@@ -29,7 +29,6 @@ using System.Xml;
 
 using NDesk.DBus;
 using org.freedesktop.DBus;
-using Tapioca;
 
 using Gtk;
 using Gnome;
@@ -52,8 +51,6 @@ namespace Banter
 		//private NotificationArea tray;
 		private Gdk.Pixbuf appPixBuf;
 		private Gnome.Program program = null;
-		private Dictionary <uint, Person> persons;
-		private Dictionary <string, ChatWindow> chatWindows;
 		private PreferencesDialog preferencesDialog;
 		
 		private Dictionary<GroupWindow, GroupWindow> groupWindows;
@@ -110,8 +107,9 @@ namespace Banter
 						Gnome.Modules.UI,
 						args);
 
-			// Call Init before anything so the people objects are in place
+			// Initialize the singleton classes to be used in the app
 			PersonManager.Instance.Init();
+			ChatWindowManager.Instance.Init();
 			
 			// Create and start up the Person Sync
 			personSync = new PersonSync();
@@ -130,7 +128,6 @@ namespace Banter
 			application = this;
 			
 			groupWindows = new Dictionary<GroupWindow, GroupWindow> ();
-			chatWindows = new Dictionary<string,ChatWindow> ();
 
 			GLib.Idle.Add(InitializeIdle);
 		}
@@ -195,7 +192,6 @@ namespace Banter
 		private void OnAccountManagementReadyEvent ()
 		{
 			Logger.Debug ("OnAccountManagementReady() called");
-			InitializePersons();
 			initialized = true;
 			
 			GLib.Idle.Add (OpenSavedGroupWindows);
@@ -234,57 +230,16 @@ namespace Banter
 			return false; // Prevent GLib.Idle from calling this method again
 		}
 
-		private void InitializePersons()
-		{
-			Logger.Debug("InitializePersons called");
-
-			persons = new Dictionary<uint,Person> ();
-
-			/*
-			try
-			{
-				Banter.Account rtcAccount = null;
-				foreach (Banter.Account account in AccountManagement.GetAccounts())
-				{
-					rtcAccount = account;
-					break;
-				}
-				
-				if (rtcAccount == null)
-					throw new ApplicationException ("No Available accounts to connect to");
-	
-				rtcAccount.Connect (false);
-				
-				if (rtcAccount.Connected == false)
-				{
-					throw new ApplicationException (
-								String.Format ("Failed to connect \"{0}\"", 
-									rtcAccount.Username));
-									//rtcAccount.TelepathyBusName));
-				}
-			}
-			catch (Exception es)
-			{
-				Console.WriteLine (es.Message);
-				Console.WriteLine (es.StackTrace);
-			}
-			finally
-			{
-			}
-			*/
-		}
-
 		private void OnImageClick (object o, ButtonPressEventArgs args) // handler for mouse click
 		{
 			if(!initialized)
 				return;
 				
 			if (args.Event.Button == 1) {
-				Console.WriteLine ("left button clicked");
+				Logger.Debug ("left button clicked");
 			} else if (args.Event.Button == 3) //right click
    			{
    				// FIXME: Eventually get all these into UIManagerLayout.xml file
-   				Console.WriteLine ("Right button clicked");
       			Menu popupMenu = new Menu();
       			
       			if (groupWindows.Count > 0) {
@@ -337,7 +292,7 @@ namespace Banter
 
 		private void OnAccounts (object o, System.EventArgs args)
 		{
-			Console.WriteLine ("Selected Accounts");
+			Logger.Debug ("Selected Accounts");
 		}
 		
 		private void OnPreferences (object sender, EventArgs args)
@@ -348,7 +303,6 @@ namespace Banter
 		private void OnGroupWindowMenuItem (object sender, EventArgs args)
 		{
 			GroupWindowMenuItem item = sender as GroupWindowMenuItem;
-			
 			item.GroupWindow.Present ();
 		}
 
@@ -455,11 +409,8 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 			try 
 			{
 				Utilities.SetProcessName ("Banter");
-
 				BusG.Init ();
-
 				application = GetApplicationWithArgs(args);
-
 				Banter.Application.RegisterSessionManagerRestart (
 					Environment.GetEnvironmentVariable ("RTC_PATH"),
 					args);
@@ -560,95 +511,6 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 		{
 			program.Run ();
 		}
-		
-		
-		public Person GetPersonFromContact(Tapioca.Contact contact)
-		{	
-			Logger.Debug ("Application.GetPerson ({0})", contact.Uri);
-			if(persons.ContainsKey(contact.Handle.Id)) {
-				Person person = persons[contact.Handle.Id];
-				Logger.Debug("Found the person: {0}", person.DisplayName);
-				return person;
-			}
-			
-			throw new ApplicationException("Fixme: The dude is not found, create real exceptions");
-		}
-		
-		public void InitiateChat(Person person)
-		{
-			Logger.Debug ("Called to initiate chat with: " + person.DisplayName);
-			
-			if (ChatWindow.AlreadyExist (person.Id) == true)
-				ChatWindow.PresentWindow (person.Id);
-			else
-			{
-				try
-				{
-					// FIXEME::temporary hack
-				
-					Banter.Account acct = null;
-					foreach (Banter.Account account in AccountManagement.GetAccounts())
-					{
-						acct = account;
-						break;
-					}
-				
-					Conversation conversation = 
-						Banter.ConversationManager.Create (acct, person, true);
-				}
-				catch (Exception es)
-				{
-					Console.WriteLine (es.Message);
-					Console.WriteLine (es.StackTrace);
-				}
-			}
-		}
-
-		public void InitiateVideoChat(Person person)
-		{
-			Logger.Debug ("Called to initiate Video chat with: " + person.DisplayName);
-			
-			VideoWindow meWindow = new VideoWindow();
-			meWindow.Title = "Me";
-			meWindow.Show();
-			
-			VideoWindow youWindow = new VideoWindow();
-			youWindow.Title = "You";
-			youWindow.Show();
-			
-			/*
-			if (this.conversation == null)
-			{
-				this.conversation = new Conversation (tapConnection, person);
-				this.conversation.SetVideoWindows (meWindow.WindowId, youWindow.WindowId);
-				this.conversation.StartVideoChat ();
-			}
-			*/
-		}		
-
-		public void InitiateAudioChat (Person person)
-		{
-			Logger.Debug ("Called to initiate Audio chat with: " + person.DisplayName);
-
-			/*			
-			if (this.conversation == null)
-			{
-				this.conversation = new Conversation (tapConnection, person);
-				this.conversation.StartAudioChat ();
-			}
-			*/
-		}		
-		
-		private void OnChatWindowDelete (object sender, DeleteEventArgs args)
-		{
-			ChatWindow cw = sender as ChatWindow;
-			if (chatWindows.ContainsValue (cw))
-			{
-				Person person = persons[cw.Conversation.PeerUser.Contact.Handle.Id];
-				if(person != null)
-					chatWindows.Remove (person.Id);
-			}
-		}
 
 		public void QuitMainLoop ()
 		{
